@@ -299,7 +299,7 @@ UTA <- function(performanceTable, criteriaMinMax, criteriaNumberOfBreakPoints, e
   indifferenceConstraints <-matrix(nrow=0, ncol=sum(criteriaNumberOfBreakPoints)+numAlt)
   
   if (!is.null(alternativesRanks)){
-
+    
     # determine now in which order the alternatives should be treated for the constraints
     indexOrder <- c()
     orderedAlternativesRanks <- sort(alternativesRanks)
@@ -489,6 +489,18 @@ UTA <- function(performanceTable, criteriaMinMax, criteriaNumberOfBreakPoints, e
   
   names(valueFunctions) <- colnames(performanceTable)
   
+  # it might happen on certain computers that these value functions 
+  # do NOT respect the monotonicity constraints (especially because of too small differences and computer arithmetics)
+  # therefore we check if they do, and if not, we "correct" them
+  
+  for (i in 1:numCrit){
+    for (j in 1:(criteriaNumberOfBreakPoints[i]-1)){
+      if (valueFunctions[[i]][2,j] > valueFunctions[[i]][2,j+1]){
+        valueFunctions[[i]][2,j+1] <- valueFunctions[[i]][2,j] 
+      }
+    }
+  }
+  
   # -------------------------------------------------------
   
   overallValues <- as.vector(t(a[,1:sum(criteriaNumberOfBreakPoints)]%*%lpSolution$solution[1:sum(criteriaNumberOfBreakPoints)]))
@@ -512,7 +524,7 @@ UTA <- function(performanceTable, criteriaMinMax, criteriaNumberOfBreakPoints, e
   # -------------------------------------------------------
   
   if ((numAlt >= 3) && !is.null(alternativesRanks))
-    tau = Kendall(alternativesRanks,outRanks)$tau[1]
+    tau = cor(alternativesRanks,outRanks,method="kendall")
   else
     tau = NULL
   
